@@ -1,5 +1,5 @@
 import torch
-from qtorch import Number, FixedPoint, BlockFloatingPoint, FloatingPoint, Posit
+from qtorch_plus import Number, FixedPoint, BlockFloatingPoint, FloatingPoint, Posit
 import torch.nn as nn
 import torch.nn.functional as F
 import numpy as np
